{% extends 'workbench.html' %}
{% load i18n %}
{% block content %}

<div class="container-fluid">
    <div class="row">
        <div class="col"></div>
        <div class="col-6">
            {% if mailing_lists.exists %}
                <h4>{% translate "The subscriptions for: " %}{{ email_contact.address }}</h4>
                <ul class="list-group">
                    {% for mailing_list in mailing_lists.all %}
                        <li class="list-group-item">
                            {{ mailing_list.title }} <a class="btn btn-outline-primary btn-sm" href="{% url 'wbmailing:unsubscribe' email_contact.id mailing_list.id %}">{% translate "Unsubscribe" %}</a>
                        </li>
                    {% endfor %}
                <ul>
            {% else %}
                <h4>{% translate "No Subscriptions For: " %}{{ email_contact.address }}</h4>
            {% endif %}
        </div>
        <div class="col"></div>
    </div>
</div>

{% endblock content %}
